Module expr_fn

Module expr_fn 

Functions

avg
Returns the average value of a given column
collect_list
Returns a list created from the values in a column
collect_set
Returns a set created from the values in a column
try_sum
Returns the sum of values for a column, or NULL if overflow occurs