pub struct SparkArrayContains { /* private fields */ }Expand description
Spark-compatible array_contains function.
Calls DataFusion’s array_has and then applies Spark’s null semantics:
- If the result from
array_hasistrue, returntrue. - If the result is
falseand the input array row contains any null elements, returnnull(because the element might have been the null). - If the result is
falseand the input array row has no null elements, returnfalse.
Implementations