Module expr_fn

Module expr_fn 

Functions

array
Returns an array with the given elements.
array_repeat
returns an array containing element count times.
shuffle
Returns a random permutation of the given array.
slice
Returns a slice of the array from the start index with the given length.
spark_array_contains
Returns true if the array contains the element (Spark semantics).