Module slice

Module slice 

Structs

SparkSlice
Spark slice function implementation Main difference from DataFusion’s array_slice is that the third argument is the length of the slice and not the end index. https://spark.apache.org/docs/latest/api/sql/index.html#slice