Module expr_fn

Module expr_fn 

Functions

bitmap_bit_position
Returns the bit position for the given input child expression.
bitmap_bucket_number
Returns the bucket number for the given input child expression.
bitmap_count
Returns the number of set bits in the input bitmap.