add_months

Function add_months 

pub fn add_months(arg1: Expr, arg2: Expr) -> Expr
Returns the date that is months months after start. The function returns NULL if at least one of the input parameters is NULL.