Module expr_fn

Module expr_fn 

Functions

crc32
crc32(expr) - Returns a cyclic redundancy check value of the expr as a bigint.
sha1
sha1(expr) - Returns a SHA-1 hash value of the expr as a hex string.
sha2
sha2(expr, bitLength) - Returns a checksum of SHA-2 family as a hex string of expr. SHA-224, SHA-256, SHA-384, and SHA-512 are supported. Bit length of 0 is equivalent to 256.
xxhash64
xxhash64(expr1, expr2, …) - Returns a 64-bit hash value of the arguments using xxHash.