Module expr_fn

Module expr_fn 

Functions

map_from_arrays
Creates a map from arrays of keys and values.
map_from_entries
Creates a map from array<struct<key, value>>.
str_to_map
Creates a map after splitting the text into key/value pairs using delimiters.