Functions
- array
- Returns an array with the given elements.
- array_
repeat - returns an array containing element count times.
- shuffle
- Returns a random permutation of the given array.
- slice
- Returns a slice of the array from the start index with the given length.
- spark_
array_ contains - Returns true if the array contains the element (Spark semantics).