Skip to main content Module expr_fn Copy item path Source date_add Returns the date that is days days after start. The function returns NULL if at least one of the input parameters is NULL. date_sub Returns the date that is days days before start. The function returns NULL if at least one of the input parameters is NULL. hour Extracts the hour component of a timestamp. last_day Returns the last day of the month which the date belongs to. make_dt_interval Make a day time interval from given days, hours, mins and secs (return type is actually a Duration(Microsecond)) make_interval Make interval from years, months, weeks, days, hours, mins and secs. minute Extracts the minute component of a timestamp. next_day Returns the first date which is later than start_date and named as indicated. The function returns NULL if at least one of the input parameters is NULL. second Extracts the second component of a timestamp.