Functions
- date_
add - Returns the date that is days days after start. The function returns NULL if at least one of the input parameters is NULL.
- date_
sub - Returns the date that is days days before start. The function returns NULL if at least one of the input parameters is NULL.
- hour
- Extracts the hour component of a timestamp.
- last_
day - Returns the last day of the month which the date belongs to.
- make_
dt_ interval - Make a day time interval from given days, hours, mins and secs (return type is actually a Duration(Microsecond))
- make_
interval - Make interval from years, months, weeks, days, hours, mins and secs.
- minute
- Extracts the minute component of a timestamp.
- next_
day - Returns the first date which is later than start_date and named as indicated. The function returns NULL if at least one of the input parameters is NULL.
- second
- Extracts the second component of a timestamp.