Module expr_fn

Module expr_fn 

Functions

abs
Returns abs(expr)
bin
Returns the string representation of the long value represented in binary.
csc
Returns the cosecant of expr.
expm1
Returns exp(expr) - 1 as a Float64.
factorial
Returns the factorial of expr. expr is [0..20]. Otherwise, null.
hex
Computes hex value of the given column.
modulus
Returns the remainder of division of the first argument by the second argument.
negative
Returns the negation of expr (unary minus).
pmod
Returns the positive remainder of division of the first argument by the second argument.
rint
Returns the double value that is closest in value to the argument and is equal to a mathematical integer.
sec
Returns the secant of expr.
unhex
Converts hexadecimal string to binary.
width_bucket
Returns the bucket number into which the value of this expression would fall after being evaluated.